# Sentiment Analysis Library

Library untuk analisis sentimen menggunakan SVM dan TF-IDF.

## Instalasi

pip install sentiment_analysis

## Penggunaan

from sentiment_analysis.main import main

main()

## Kontribusi

Silakan buka isu atau pull request di [GitHub](https://github.com/nama_anda/sentiment_analysis).

## Lisensi

[MIT](LICENSE)
